==> merge-ats-client-1.0.0.tar.gz: merge-ats-client-1.0.0/MergeATSClient/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.account_token_api import AccountTokenApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from MergeATSClient.api.account_token_api import AccountTokenApi
from MergeATSClient.api.activities_api import ActivitiesApi
from MergeATSClient.api.applications_api import ApplicationsApi
from MergeATSClient.api.attachments_api import AttachmentsApi
from MergeATSClient.api.available_actions_api import AvailableActionsApi
from MergeATSClient.api.candidates_api import CandidatesApi
from MergeATSClient.api.departments_api import DepartmentsApi
from MergeATSClient.api.eeocs_api import EeocsApi
from MergeATSClient.api.generate_key_api import GenerateKeyApi
from MergeATSClient.api.interviews_api import InterviewsApi
from MergeATSClient.api.job_interview_stages_api import JobInterviewStagesApi
from MergeATSClient.api.jobs_api import JobsApi
from MergeATSClient.api.link_token_api import LinkTokenApi
from MergeATSClient.api.offers_api import OffersApi
from MergeATSClient.api.offices_api import OfficesApi
from MergeATSClient.api.passthrough_api import PassthroughApi
from MergeATSClient.api.regenerate_key_api import RegenerateKeyApi
from MergeATSClient.api.reject_reasons_api import RejectReasonsApi
from MergeATSClient.api.scorecards_api import ScorecardsApi
from MergeATSClient.api.sync_status_api import SyncStatusApi
from MergeATSClient.api.tags_api import TagsApi
from MergeATSClient.api.users_api import UsersApi

==> merge-ats-client-1.2.0.tar.gz: merge-ats-client-1.2.0/MergeATSClient/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.account_details_api import AccountDetailsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from MergeATSClient.api.account_details_api import AccountDetailsApi
from MergeATSClient.api.account_token_api import AccountTokenApi
from MergeATSClient.api.activities_api import ActivitiesApi
from MergeATSClient.api.applications_api import ApplicationsApi
from MergeATSClient.api.attachments_api import AttachmentsApi
from MergeATSClient.api.available_actions_api import AvailableActionsApi
from MergeATSClient.api.candidates_api import CandidatesApi
from MergeATSClient.api.delete_account_api import DeleteAccountApi
from MergeATSClient.api.departments_api import DepartmentsApi
from MergeATSClient.api.eeocs_api import EeocsApi
from MergeATSClient.api.generate_key_api import GenerateKeyApi
from MergeATSClient.api.interviews_api import InterviewsApi
from MergeATSClient.api.issues_api import IssuesApi
from MergeATSClient.api.job_interview_stages_api import JobInterviewStagesApi
from MergeATSClient.api.jobs_api import JobsApi
from MergeATSClient.api.link_token_api import LinkTokenApi
from MergeATSClient.api.linked_accounts_api import LinkedAccountsApi
from MergeATSClient.api.offers_api import OffersApi
from MergeATSClient.api.offices_api import OfficesApi
from MergeATSClient.api.passthrough_api import PassthroughApi
from MergeATSClient.api.regenerate_key_api import RegenerateKeyApi
from MergeATSClient.api.reject_reasons_api import RejectReasonsApi
from MergeATSClient.api.scorecards_api import ScorecardsApi
from MergeATSClient.api.sync_status_api import SyncStatusApi
from MergeATSClient.api.tags_api import TagsApi
from MergeATSClient.api.users_api import UsersApi
